from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="Championship")


@_attrs_define
class Championship:
    """
    Attributes:
        id (int | Unset):
        organization (int | Unset):
        championshipid (int | Unset):
        name (str | Unset):
        season (str | Unset):
        html (str | Unset):
        xml (str | Unset):
        backupxml (str | Unset):
    """

    id: int | Unset = UNSET
    organization: int | Unset = UNSET
    championshipid: int | Unset = UNSET
    name: str | Unset = UNSET
    season: str | Unset = UNSET
    html: str | Unset = UNSET
    xml: str | Unset = UNSET
    backupxml: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        organization = self.organization

        championshipid = self.championshipid

        name = self.name

        season = self.season

        html = self.html

        xml = self.xml

        backupxml = self.backupxml

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if championshipid is not UNSET:
            field_dict["championshipid"] = championshipid
        if name is not UNSET:
            field_dict["name"] = name
        if season is not UNSET:
            field_dict["season"] = season
        if html is not UNSET:
            field_dict["html"] = html
        if xml is not UNSET:
            field_dict["xml"] = xml
        if backupxml is not UNSET:
            field_dict["backupxml"] = backupxml

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        organization = d.pop("organization", UNSET)

        championshipid = d.pop("championshipid", UNSET)

        name = d.pop("name", UNSET)

        season = d.pop("season", UNSET)

        html = d.pop("html", UNSET)

        xml = d.pop("xml", UNSET)

        backupxml = d.pop("backupxml", UNSET)

        championship = cls(
            id=id,
            organization=organization,
            championshipid=championshipid,
            name=name,
            season=season,
            html=html,
            xml=xml,
            backupxml=backupxml,
        )

        championship.additional_properties = d
        return championship

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    vendor_id: str | Unset = UNSET,
    package_id: str | Unset = UNSET,
    login_name: str | Unset = UNSET,
    login_pass: str | Unset = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["VendorID"] = vendor_id

    params["PackageID"] = package_id

    params["loginName"] = login_name

    params["loginPass"] = login_pass

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "options",
        "url": "/upload/thirdparty/signin.jsp",
        "params": params,
    }

    return _kwargs


def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Any | None:
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    vendor_id: str | Unset = UNSET,
    package_id: str | Unset = UNSET,
    login_name: str | Unset = UNSET,
    login_pass: str | Unset = UNSET,
) -> Response[Any]:
    """
    Args:
        vendor_id (str | Unset):
        package_id (str | Unset):
        login_name (str | Unset):
        login_pass (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        vendor_id=vendor_id,
        package_id=package_id,
        login_name=login_name,
        login_pass=login_pass,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    vendor_id: str | Unset = UNSET,
    package_id: str | Unset = UNSET,
    login_name: str | Unset = UNSET,
    login_pass: str | Unset = UNSET,
) -> Response[Any]:
    """
    Args:
        vendor_id (str | Unset):
        package_id (str | Unset):
        login_name (str | Unset):
        login_pass (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        vendor_id=vendor_id,
        package_id=package_id,
        login_name=login_name,
        login_pass=login_pass,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="UploadLogin1DataBody")


@_attrs_define
class UploadLogin1DataBody:
    """
    Attributes:
        login_name (str):
        login_pass (str):
    """

    login_name: str
    login_pass: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        login_name = self.login_name

        login_pass = self.login_pass

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "loginName": login_name,
                "loginPass": login_pass,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        login_name = d.pop("loginName")

        login_pass = d.pop("loginPass")

        upload_login_1_data_body = cls(
            login_name=login_name,
            login_pass=login_pass,
        )

        upload_login_1_data_body.additional_properties = d
        return upload_login_1_data_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
